@@ -146,7 +146,7 @@ class XMLWriter {
 			writer.print('<');
 			final String fullName = xml.getFullName();
 			writer.print(fullName);
-			final Vector nsprefixes = new Vector();
+			final Vector<String> nsprefixes = new Vector<String>();
 			if (xml.getNamespace() != null) {
 				if (xml.getName().equals(fullName)) {
 					writer.print(" xmlns=\"" + xml.getNamespace() + '"');
@@ -159,9 +159,9 @@ class XMLWriter {
 					writer.print("=\"" + xml.getNamespace() + "\"");
 				}
 			}
-			Enumeration enumeration = xml.enumerateAttributeNames();
-			while (enumeration.hasMoreElements()) {
-				final String key = (String) enumeration.nextElement();
+			Enumeration<String> enumAttributeNames = xml.enumerateAttributeNames();
+			while (enumAttributeNames.hasMoreElements()) {
+				final String key = (String) enumAttributeNames.nextElement();
 				final int index = key.indexOf(':');
 				if (index >= 0) {
 					final String namespace = xml.getAttributeNamespace(key);
@@ -175,9 +175,9 @@ class XMLWriter {
 					}
 				}
 			}
-			enumeration = xml.enumerateAttributeNames();
-			while (enumeration.hasMoreElements()) {
-				final String key = (String) enumeration.nextElement();
+			enumAttributeNames = xml.enumerateAttributeNames();
+			while (enumAttributeNames.hasMoreElements()) {
+				final String key = (String) enumAttributeNames.nextElement();
 				final String value = xml.getAttribute(key, null);
 				writer.print(" " + key + "=\"");
 				this.writeEncoded(value, true, false);
@@ -195,9 +195,9 @@ class XMLWriter {
 				if (prettyPrint) {
 					writer.println();
 				}
-				enumeration = xml.enumerateChildren();
+				Enumeration<XMLElement> enumeration = xml.enumerateChildren();
 				while (enumeration.hasMoreElements()) {
-					final XMLElement child = (XMLElement) enumeration.nextElement();
+					final XMLElement child = enumeration.nextElement();
 					this.write(child, prettyPrint, indent + 4, collapseEmptyElements, true);
 				}
 				if (prettyPrint) {
@@ -225,10 +225,6 @@ class XMLWriter {
 
 	/**
 	 * Writes a string encoding reserved characters.
-	 * 
-	 * @param str
-	 *            the string to write.
-	 * @param atributeValue TODO
 	 */
 	private void writeEncoded(final String str, final boolean atributeValue, final boolean xmlInclude) {
 		for (int i = 0; i < str.length(); i++) {
