@@ -19,32 +19,19 @@
  */
 package org.freeplane.core.ui;
 
-import javax.swing.event.PopupMenuEvent;
-import javax.swing.event.PopupMenuListener;
+import java.awt.event.HierarchyEvent;
+import java.awt.event.HierarchyListener;
 
-import org.freeplane.core.modecontroller.ModeController;
+import org.freeplane.features.mode.Controller;
 
 /**
  * listener, that blocks the controler if the menu is active (PN) Take care!
  * This listener is also used for modelpopups (as for graphical links).
  */
-public class ControllerPopupMenuListener implements PopupMenuListener {
-	ModeController modeController;
-
-	public ControllerPopupMenuListener(final ModeController modeController) {
-		super();
-		this.modeController = modeController;
-	}
-
-	public void popupMenuCanceled(final PopupMenuEvent e) {
-		modeController.setBlocked(false);
-	}
-
-	public void popupMenuWillBecomeInvisible(final PopupMenuEvent e) {
-		modeController.setBlocked(false);
-	}
-
-	public void popupMenuWillBecomeVisible(final PopupMenuEvent e) {
-		modeController.setBlocked(true);
-	}
-}
+public class ControllerPopupMenuListener implements HierarchyListener {
+    
+    public void hierarchyChanged(HierarchyEvent e) {
+        if(e.getID() != HierarchyEvent.ANCESTOR_MOVED && e.getID() != HierarchyEvent.ANCESTOR_RESIZED)
+            Controller.getCurrentModeController().setBlocked(e.getComponent().isShowing());
+    }
+ }
