@@ -29,4 +29,9 @@ public interface IFreeplaneAction extends Action {
 	public void afterMapChange(Object newMap);
 
 	public boolean isSelected();
+
+	public void setSelected(boolean b);
+
+	public String getIconKey();
+
 }
