@@ -3,11 +3,13 @@ package org.freeplane.features.clipboard;
 import java.awt.datatransfer.StringSelection;
 import java.awt.event.ActionEvent;
 import java.io.File;
+
 import org.freeplane.core.ui.AFreeplaneAction;
 import org.freeplane.core.ui.components.UITools;
 import org.freeplane.core.util.TextUtils;
 import org.freeplane.features.map.NodeModel;
 import org.freeplane.features.mode.Controller;
+import org.freeplane.features.url.FreeplaneUriConverter;
 
 public class CopyNodeURIAction extends AFreeplaneAction {
 	public CopyNodeURIAction() {
@@ -15,10 +17,9 @@ public class CopyNodeURIAction extends AFreeplaneAction {
 	}
 
 	/**
-	 * 
+	 *
 	 */
 	private static final long serialVersionUID = 1L;
-
 	public void actionPerformed(final ActionEvent e) {
 		final Controller controller = Controller.getCurrentController();
 		final NodeModel node = controller.getSelection().getSelected();
@@ -27,10 +28,16 @@ public class CopyNodeURIAction extends AFreeplaneAction {
 			UITools.errorMessage(TextUtils.getRawText("map_not_saved"));
 			return;
 		}
-		final String idString = mindmapFile.toURI().toString() + '#' + node.createID();
-		final ClipboardController clipboardController = (ClipboardController) Controller.getCurrentModeController().getExtension(
+		final String idString = uri(node, mindmapFile);
+		final ClipboardController clipboardController = Controller.getCurrentModeController().getExtension(
 		    ClipboardController.class);
 		clipboardController.setClipboardContents(new StringSelection(idString));
 		controller.getViewController().out(idString);
 	}
+
+	public String uri(final NodeModel node, File mindmapFile) {
+	    final String fileBasedUri = mindmapFile.toURI().toString() + '#' + node.createID();
+		final FreeplaneUriConverter freeplaneUriConverter = new FreeplaneUriConverter();
+		return freeplaneUriConverter.freeplaneUriForFile(fileBasedUri);
+    }
 }
