@@ -93,6 +93,7 @@ import org.freeplane.features.text.ShortenedTextModel;
 import org.freeplane.features.text.TextController;
 import org.freeplane.features.text.mindmapmode.EditNodeBase.EditedComponent;
 import org.freeplane.features.text.mindmapmode.EditNodeBase.IEditControl;
+import org.freeplane.features.ui.IMapViewManager;
 import org.freeplane.features.ui.ViewController;
 import org.freeplane.features.url.UrlManager;
 
@@ -168,6 +169,8 @@ public class MTextController extends TextController {
 				}
 				int secondStart = 0;
 				int secondLen = doc.getLength() - pos;
+				if(secondLen <= 0)
+					return null;
 				final char[] secondText = doc.getText(pos, secondLen).toCharArray();
 				while ((secondStart < secondLen) && (secondText[secondStart] <= ' ')) {
 					secondStart++;
@@ -288,7 +291,7 @@ public class MTextController extends TextController {
 					picturesAmongSelecteds = true;
 					final String encodedLinkString = HtmlUtils.unicodeToHTMLUnicodeEntity(linkString);
 					final String strText = "<html><img src=\"" + encodedLinkString + "\">";
-					((MLinkController) LinkController.getController()).setLink(node, (URI) null, false);
+					((MLinkController) LinkController.getController()).setLink(node, (URI) null, LinkController.LINK_ABSOLUTE);
 					setNodeText(node, strText);
 				}
 			}
@@ -301,9 +304,7 @@ public class MTextController extends TextController {
 		final NodeModel selectedNode = modeController.getMapController().getSelectedNode();
 		final MapModel map = selectedNode.getMap();
 		final File file = map.getFile();
-		final boolean useRelativeUri = ResourceController.getResourceController().getProperty("links").equals(
-		    "relative");
-		if (file == null && useRelativeUri) {
+		if (file == null && LinkController.getLinkType() == LinkController.LINK_RELATIVE_TO_MINDMAP) {
 			JOptionPane.showMessageDialog(viewController.getContentPane(), TextUtils
 			    .getText("not_saved_for_image_error"), "Freeplane", JOptionPane.WARNING_MESSAGE);
 			return;
@@ -330,14 +331,14 @@ public class MTextController extends TextController {
 		}
 		// bad hack: try to interpret file as http link
 		if(! input.exists()){
-			uri = LinkController.toRelativeURI(map.getFile(), input);
+			uri = LinkController.toRelativeURI(map.getFile(), input, LinkController.LINK_RELATIVE_TO_MINDMAP);
 			if(uri == null || ! "http".equals(uri.getScheme())){
 				UITools.errorMessage(TextUtils.format("file_not_found", input.toString()));
 				return;
 			}
 		}
-		else if (useRelativeUri) {
-			uri = LinkController.toRelativeURI(map.getFile(), input);
+		else if (LinkController.getLinkType() != LinkController.LINK_ABSOLUTE) {
+			uri = LinkController.toLinkTypeDependantURI(map.getFile(), input);
 		}
 		String uriString = uri.toString();
 		if(uriString.startsWith("http:/")){
@@ -522,7 +523,7 @@ public class MTextController extends TextController {
             }
 		};
 		mCurrentEditDialog = createEditor(nodeModel, editControl, text, false, editLong, true);
-		final RootPaneContainer frame = (RootPaneContainer) SwingUtilities.getWindowAncestor(controller.getViewController().getMapView());
+		final RootPaneContainer frame = (RootPaneContainer) SwingUtilities.getWindowAncestor(controller.getMapViewManager().getMapViewComponent());
 		mCurrentEditDialog.show(frame);
     }
 
@@ -595,7 +596,7 @@ public class MTextController extends TextController {
 				final DetailTextModel details = DetailTextModel.createDetailText(node);
 				details.setHidden(isHidden);
 				node.addExtension(details);
-				Controller.getCurrentModeController().getMapController().nodeChanged(node, "DETAILS_HIDDEN", ! isHidden, isHidden);
+				Controller.getCurrentModeController().getMapController().nodeChanged(node, DETAILS_HIDDEN, ! isHidden, isHidden);
 			}
 
 			public void undo() {
@@ -751,8 +752,8 @@ public class MTextController extends TextController {
 		if (controller.getMap() != nodeModel.getMap()) {
 			return;
 		}
-		final ViewController viewController = controller.getViewController();
-		final Component map = viewController.getMapView();
+		final IMapViewManager viewController = controller.getMapViewManager();
+		final Component map = viewController.getMapViewComponent();
 		map.validate();
 		map.invalidate();
 		final Component node = viewController.getComponent(nodeModel);
@@ -951,4 +952,3 @@ public class MTextController extends TextController {
 	}
 
 }
-
