@@ -20,6 +20,7 @@
 package org.freeplane.main.applet;
 
 import java.awt.BorderLayout;
+import java.awt.Component;
 import java.awt.EventQueue;
 import java.lang.reflect.InvocationTargetException;
 import java.net.MalformedURLException;
@@ -29,6 +30,7 @@ import java.net.URL;
 import javax.swing.JComponent;
 import javax.swing.JFrame;
 import javax.swing.JPanel;
+import javax.swing.JScrollPane;
 import javax.swing.RootPaneContainer;
 import javax.swing.SwingUtilities;
 
@@ -41,21 +43,25 @@ import org.freeplane.core.util.TextUtils;
 import org.freeplane.features.map.IMapSelection;
 import org.freeplane.features.mode.Controller;
 import org.freeplane.features.mode.browsemode.BModeController;
+import org.freeplane.features.ui.FrameController;
+import org.freeplane.features.ui.IMapViewChangeListener;
 import org.freeplane.features.ui.IMapViewManager;
-import org.freeplane.features.ui.ViewController;
+import org.freeplane.view.swing.map.MapViewScrollPane;
 
 /**
  * @author Dimitry Polivaev
  */
-class AppletViewController extends ViewController {
+class AppletViewController extends FrameController implements IMapViewChangeListener {
 	final private FreeplaneApplet applet;
 	private JComponent mComponentInSplitPane;
 	private JComponent mapContentBox;
+	private JScrollPane scrollPane;
 
 	public AppletViewController( final FreeplaneApplet applet, Controller controller,
 	                            final IMapViewManager mapViewController) {
 		super(controller, mapViewController, "");
 		this.applet = applet;
+		mapViewController.addMapViewChangeListener(this);
 	}
 
 	/*
@@ -88,7 +94,8 @@ class AppletViewController extends ViewController {
 	@Override
 	public void init(Controller controller) {
 		mapContentBox = new JPanel(new BorderLayout());
-		mapContentBox.add(getScrollPane(), BorderLayout.CENTER);
+		scrollPane = new MapViewScrollPane();
+		mapContentBox.add(scrollPane, BorderLayout.CENTER);
 		getContentPane().add(mapContentBox, BorderLayout.CENTER);
 		super.init(controller);
 		SwingUtilities.updateComponentTreeUI(applet);
@@ -109,10 +116,10 @@ class AppletViewController extends ViewController {
 		getController().selectMode(BModeController.MODENAME);
 		String initialMapName = ResourceController.getResourceController().getProperty("browsemode_initial_map");
 		if (initialMapName != null && initialMapName.startsWith(".")) {
-			/* new handling for relative urls. fc, 29.10.2003. */
+			final String locationUrl = applet.getParameter("location_href");
 			try {
-				URI uri = applet.getDocumentBase().toURI().resolve(new URI(null, null, initialMapName, null));
-				URL documentBase = new URL(uri.getScheme(), uri.getHost(), uri.getPath());
+				URI uri = new URI(locationUrl).resolve(new URI(null, null, initialMapName, null));
+				URL documentBase = new URL(uri.getScheme(), uri.getHost(),  uri.getPort(), uri.getPath());
 				initialMapName = documentBase.toString();
 			}
 			catch (final Exception e) {
@@ -195,7 +202,7 @@ class AppletViewController extends ViewController {
 	}
 
 	@Override
-	public void setTitle(final String title) {
+	public void setTitle(final String frameTitle) {
 	}
 
 	@Override
@@ -217,4 +224,18 @@ class AppletViewController extends ViewController {
 			LogUtils.severe(e);
 		}
 	}
+
+	public void afterViewChange(Component oldView, Component newView) {
+		if(scrollPane != null)
+			scrollPane.setViewportView(newView);
+    }
+
+	public void afterViewClose(Component oldView) {
+    }
+
+	public void afterViewCreated(Component mapView) {
+    }
+
+	public void beforeViewChange(Component oldView, Component newView) {
+    }
 }
