@@ -68,14 +68,10 @@ import org.freeplane.n3.nanoxml.XMLException;
 class LastOpenedList implements IMapViewChangeListener, IMapChangeListener {
 	private static final String MENU_CATEGORY = "main_menu_most_recent_files";
 	private static final String LAST_OPENED_LIST_LENGTH = "last_opened_list_length";
-	private static final String OPENED_NOW = "openedNow_1.0.20";
 	private static final String LAST_OPENED = "lastOpened_1.0.20";
-	public static final String LOAD_LAST_MAP = "load_last_map";
-	public static final String LOAD_LAST_MAPS = "load_last_maps";
-// // 	private final Controller controller;
+	// // 	private final Controller controller;
 	private static boolean PORTABLE_APP = System.getProperty("portableapp", "false").equals("true");
 	private static String USER_DRIVE = System.getProperty("user.home", "").substring(0, 2);
-	final private List<String> currenlyOpenedList = new LinkedList<String>();
 	/**
 	 * Contains Restore strings.
 	 */
@@ -84,10 +80,11 @@ class LastOpenedList implements IMapViewChangeListener, IMapChangeListener {
 	 * Contains Restore string => map name (map.toString()).
 	 */
 	final private Map<String, String> mRestorableToMapName = new HashMap<String, String>();
+	private String mapSelectedOnStart;
 
 	LastOpenedList() {
 //		this.controller = controller;
-		restoreList(LAST_OPENED, lastOpenedList);
+		restoreList(LAST_OPENED);
 	}
 
 	public void afterViewChange(final Component oldView, final Component newView) {
@@ -102,19 +99,9 @@ class LastOpenedList implements IMapViewChangeListener, IMapChangeListener {
 	}
 
 	public void afterViewClose(final Component oldView) {
-		final String restoreable = getRestoreable(oldView);
-		if (restoreable == null) {
-			return;
-		}
-		currenlyOpenedList.remove(restoreable);
 	}
 
 	public void afterViewCreated(final Component mapView) {
-		final String restoreable = getRestoreable(mapView);
-		if (restoreable == null) {
-			return;
-		}
-		currenlyOpenedList.add(restoreable);
 	}
 
 	public void beforeViewChange(final Component oldView, final Component newView) {
@@ -139,13 +126,6 @@ class LastOpenedList implements IMapViewChangeListener, IMapChangeListener {
 		return "MindMap::" + absolutePath.substring(2);
 	}
 
-	private String getRestoreable(final Component mapView) {
-		final IMapViewManager mapViewManager = Controller.getCurrentController().getMapViewManager();
-		final MapModel map = mapViewManager.getModel(mapView);
-		final String restoreString = getRestoreable(map);
-		return restoreString;
-	}
-
 	public String getRestoreable( final MapModel map) {
 		if (map == null) {
 			return null;
@@ -165,20 +145,11 @@ class LastOpenedList implements IMapViewChangeListener, IMapChangeListener {
 		if (!event.getProperty().equals(UrlManager.MAP_URL)) {
 			return;
 		}
-		final URL before = (URL) event.getOldValue();
-		if (before != null) {
-			final String fileBefore = before.getFile();
-			if (fileBefore != null) {
-				final String restorable = getRestorable(new File(fileBefore));
-				currenlyOpenedList.remove(restorable);
-			}
-		}
 		final URL after = (URL) event.getNewValue();
 		if (after != null) {
 			final String fileAfter = after.getFile();
 			if (fileAfter != null) {
 				final String restorable = getRestorable(new File(fileAfter));
-				currenlyOpenedList.add(restorable);
 				updateList(event.getMap(), restorable);
 			}
 		}
@@ -199,42 +170,33 @@ class LastOpenedList implements IMapViewChangeListener, IMapChangeListener {
 
 	public void open(final String restoreable) throws FileNotFoundException, MalformedURLException,
 	        IOException, URISyntaxException, XMLException {
-		final boolean changedToMapView = tryToChangeToMapView(restoreable);
-		if ((restoreable != null) && !(changedToMapView)) {
-			final StringTokenizer token = new StringTokenizer(restoreable, ":");
-			if (token.hasMoreTokens()) {
-				final String mode = token.nextToken();
-				Controller.getCurrentController().selectMode(mode);
-				String fileName = token.nextToken("").substring(1);
-				if (PORTABLE_APP && fileName.startsWith(":") && USER_DRIVE.endsWith(":")) {
-					fileName = USER_DRIVE + fileName.substring(1);
-				}
-				Controller.getCurrentModeController().getMapController().newMap(Compat.fileToUrl(new File(fileName)));
-			}
+		if (restoreable == null)
+			return;
+		final StringTokenizer tokens = new StringTokenizer(restoreable, ":");
+		if (!tokens.hasMoreTokens())
+			return;
+		final boolean changedToMapView;
+			changedToMapView = tryToChangeToMapView(restoreable);
+		if (changedToMapView)
+			return;
+		final String mode = tokens.nextToken();
+		Controller.getCurrentController().selectMode(mode);
+		String fileName = tokens.nextToken(";").substring(1);
+		if (PORTABLE_APP && fileName.startsWith(":") && USER_DRIVE.endsWith(":")) {
+			fileName = USER_DRIVE + fileName.substring(1);
+		}
+		if(!changedToMapView)
+			Controller.getCurrentModeController().getMapController().newMap(Compat.fileToUrl(new File(fileName)));
+		else{
+			final MapModel map = Controller.getCurrentController().getMap();
+			Controller.getCurrentModeController().getMapController().newMapView(map);
 		}
 	}
 
-	public void openMapsOnStart() {
-		final boolean loadLastMap = ResourceController.getResourceController().getBooleanProperty(LOAD_LAST_MAP);
-		final String lastMap;
-		if (loadLastMap && !lastOpenedList.isEmpty()) {
-			lastMap = lastOpenedList.get(0);
-		}
-		else {
-			lastMap = null;
-		}
-		final boolean loadLastMaps = ResourceController.getResourceController().getBooleanProperty(LOAD_LAST_MAPS);
-		if (loadLastMaps) {
-			final List<String> startList = new LinkedList<String>();
-			restoreList(OPENED_NOW, startList);
-			safeOpen(startList);
-			if (!lastOpenedList.isEmpty()) {
-				tryToChangeToMapView(lastMap);
-			}
-			return;
-		}
-		if (loadLastMap && !lastOpenedList.isEmpty()) {
-			safeOpen(lastMap);
+	void openLastMapOnStart() {
+		if (mapSelectedOnStart != null) {
+			if(!tryToChangeToMapView(mapSelectedOnStart))
+				safeOpen(mapSelectedOnStart);
 		}
 	}
 
@@ -243,10 +205,13 @@ class LastOpenedList implements IMapViewChangeListener, IMapChangeListener {
 		updateMenus();
 	}
 
-	private void restoreList(final String key, final List<String> list) {
+	private void restoreList(final String key) {
 		final String restored = ResourceController.getResourceController().getProperty(key, null);
 		if (restored != null && !restored.equals("")) {
-			list.addAll(ConfigurationUtils.decodeListValue(restored, true));
+			lastOpenedList.addAll(ConfigurationUtils.decodeListValue(restored, true));
+			if (!lastOpenedList.isEmpty()) {
+				mapSelectedOnStart = lastOpenedList.get(0);
+			}
 		}
 	}
 
@@ -275,8 +240,6 @@ class LastOpenedList implements IMapViewChangeListener, IMapChangeListener {
 	public void saveProperties() {
 		ResourceController.getResourceController().setProperty(LAST_OPENED,
 		    ConfigurationUtils.encodeListValue(lastOpenedList, true));
-		ResourceController.getResourceController().setProperty(OPENED_NOW,
-		    ConfigurationUtils.encodeListValue(currenlyOpenedList, true));
 	}
 
 	private boolean tryToChangeToMapView(final String restoreable) {
@@ -317,8 +280,9 @@ class LastOpenedList implements IMapViewChangeListener, IMapChangeListener {
 			final AFreeplaneAction lastOpenedActionListener = new OpenLastOpenedAction(i++, this);
 			final IFreeplaneAction decoratedAction = menuBuilder.decorateAction(lastOpenedActionListener);
 			final JMenuItem item = new JFreeplaneMenuItem(decoratedAction);
+			item.setActionCommand(key);
 			String text = createOpenMapItemName(key);
-			item.setText(createOpenMapItemName(text));
+			item.setText(text);
 			item.setMnemonic(0);
 			menuBuilder.addMenuItem(MENU_CATEGORY, item, MENU_CATEGORY + '/' + lastOpenedActionListener.getKey(),
 			    UIBuilder.AS_CHILD);
@@ -330,8 +294,11 @@ class LastOpenedList implements IMapViewChangeListener, IMapChangeListener {
 		if(separatorIndex == -1)
 			return restorable;
 		String key = restorable.substring(0, separatorIndex);
-		return TextUtils.getText("open_as" + key, key) + restorable.substring(separatorIndex);
-		
+		String fileName = restorable.substring(separatorIndex);
+		if(fileName.startsWith("::"))
+			return TextUtils.getText("open_as" + key, key) + " " + fileName.substring(2);
+		else
+			return TextUtils.getText("open_as" + key, key) + " " + fileName.substring(1);
     }
 
 	public void onPreNodeMoved(final NodeModel oldParent, final int oldIndex, final NodeModel newParent,
