@@ -19,7 +19,6 @@
  */
 package org.freeplane.main.osgi;
 
-import java.awt.EventQueue;
 import java.io.File;
 import java.io.FileInputStream;
 import java.io.InputStream;
@@ -38,8 +37,10 @@ import org.freeplane.core.util.LogUtils;
 import org.freeplane.features.filter.FilterController;
 import org.freeplane.features.mode.Controller;
 import org.freeplane.features.mode.ModeController;
+import org.freeplane.main.application.FreeplaneGUIStarter;
 import org.freeplane.main.application.FreeplaneStarter;
 import org.freeplane.main.application.SingleInstanceManager;
+import org.freeplane.main.headlessmode.FreeplaneHeadlessStarter;
 import org.osgi.framework.Bundle;
 import org.osgi.framework.BundleActivator;
 import org.osgi.framework.BundleContext;
@@ -53,6 +54,7 @@ import org.osgi.service.url.URLStreamHandlerService;
  * 05.01.2009
  */
 class ActivatorImpl implements BundleActivator {
+	private static final String HEADLESS_RUN_PROPERTY_NAME = FreeplaneStarter.class.getName() + ".headless";
 	private FreeplaneStarter starter;
 
 	private String[] getCallParameters() {
@@ -87,7 +89,7 @@ class ActivatorImpl implements BundleActivator {
 	}
 
 	private void loadPlugins(final BundleContext context) {
-		final String resourceBaseDir = FreeplaneStarter.getResourceBaseDir();
+		final String resourceBaseDir = FreeplaneGUIStarter.getResourceBaseDir();
 		final File baseDir = new File(resourceBaseDir).getAbsoluteFile().getParentFile();
 		List<Bundle> loadedPlugins = new LinkedList<Bundle>();
 		loadPlugins(context, new File(baseDir, "plugins"), loadedPlugins);
@@ -149,7 +151,7 @@ class ActivatorImpl implements BundleActivator {
 	private void startFramework(final BundleContext context) {
         registerClasspathUrlHandler(context);
 		if (null == System.getProperty("org.freeplane.core.dir.lib", null)) {
-			final File root = new File(FreeplaneStarter.getResourceBaseDir()).getAbsoluteFile().getParentFile();
+			final File root = new File(FreeplaneGUIStarter.getResourceBaseDir()).getAbsoluteFile().getParentFile();
 			try {
 				String rootUrl = root.toURI().toURL().toString();
 				if (!rootUrl.endsWith("/")) {
@@ -162,7 +164,7 @@ class ActivatorImpl implements BundleActivator {
 			}
 		}
 		// initialize ApplicationController - SingleInstanceManager needs the configuration
-		starter = new FreeplaneStarter();
+		starter =  createStarter();
 		final SingleInstanceManager singleInstanceManager = new SingleInstanceManager(starter);
 		singleInstanceManager.start(getCallParameters());
 		if (singleInstanceManager.isSlave()) {
@@ -213,7 +215,7 @@ class ActivatorImpl implements BundleActivator {
 			e.printStackTrace();
 		}
 		if ("true".equals(System.getProperty("org.freeplane.exit_on_start", null))) {
-			EventQueue.invokeLater(new Runnable() {
+			controller.getViewController().invokeLater(new Runnable() {
 				public void run() {
 					try {
 						Thread.sleep(1000);
@@ -225,7 +227,7 @@ class ActivatorImpl implements BundleActivator {
 			});
 			return;
 		}
-		EventQueue.invokeLater(new Runnable() {
+		controller.getViewController().invokeLater(new Runnable() {
 			public void run() {
 				final Bundle[] bundles = context.getBundles();
 				final HashSet<String> plugins = new HashSet<String>();
@@ -239,6 +241,13 @@ class ActivatorImpl implements BundleActivator {
 		});
 	}
 
+	public FreeplaneStarter createStarter() {
+		if(Boolean.getBoolean(HEADLESS_RUN_PROPERTY_NAME))
+			return new FreeplaneHeadlessStarter();
+		else
+			return new FreeplaneGUIStarter();
+    }
+
     private void registerClasspathUrlHandler(final BundleContext context) {
         Hashtable<String, String[]> properties = new Hashtable<String, String[]>();
         properties.put(URLConstants.URL_HANDLER_PROTOCOL, new String[] { ResourceController.FREEPLANE_RESOURCE_URL_PROTOCOL });
