@@ -6,6 +6,10 @@ import org.freeplane.core.resources.WindowConfigurationStorage;
 import org.freeplane.n3.nanoxml.XMLElement;
 
 class ScriptEditorWindowConfigurationStorage extends WindowConfigurationStorage {
+	public ScriptEditorWindowConfigurationStorage() {
+	    super("manage_style_editor_window_configuration_storage");
+    }
+
 	public static ScriptEditorWindowConfigurationStorage decorateDialog(final String marshalled, final JDialog dialog) {
 		final ScriptEditorWindowConfigurationStorage storage = new ScriptEditorWindowConfigurationStorage();
 		final XMLElement xml = storage.unmarschall(marshalled, dialog);
@@ -30,7 +34,6 @@ class ScriptEditorWindowConfigurationStorage extends WindowConfigurationStorage
 
 	@Override
 	protected void marshallSpecificElements(final XMLElement xml) {
-		xml.setName("manage_style_editor_window_configuration_storage");
 		xml.setAttribute("left_ratio", Integer.toString(leftRatio));
 		xml.setAttribute("top_ratio", Integer.toString(topRatio));
 	}
