@@ -41,6 +41,7 @@ import org.apache.commons.lang.StringUtils;
 import org.freeplane.core.resources.ResourceController;
 import org.freeplane.core.resources.components.IValidator;
 import org.freeplane.core.ui.IMenuContributor;
+import org.freeplane.core.ui.IUserInputListenerFactory;
 import org.freeplane.core.ui.MenuBuilder;
 import org.freeplane.core.util.FileUtils;
 import org.freeplane.core.util.LogUtils;
@@ -63,7 +64,6 @@ import org.freeplane.plugin.script.ExecuteScriptAction.ExecutionMode;
 import org.freeplane.plugin.script.ScriptEditorPanel.IScriptModel;
 import org.freeplane.plugin.script.ScriptEditorPanel.ScriptHolder;
 import org.freeplane.plugin.script.ScriptingConfiguration.ScriptMetaData;
-import org.freeplane.plugin.script.ScriptingEngine.IErrorHandler;
 import org.freeplane.plugin.script.addons.ManageAddOnsAction;
 import org.freeplane.plugin.script.addons.ManageAddOnsDialog;
 import org.freeplane.plugin.script.addons.ScriptAddOnProperties;
@@ -96,7 +96,7 @@ class ScriptingRegistration {
 			}
 		}
 
-		public Object executeScript(final int pIndex, final PrintStream pOutStream, final IErrorHandler pErrorHandler) {
+		public Object executeScript(final int pIndex, final PrintStream pOutStream, final IFreeplaneScriptErrorHandler pErrorHandler) {
 			final ModeController modeController = Controller.getCurrentModeController();
 			// the script is completely in the hand of the user -> no security issues.
 			final ScriptingPermissions restrictedPermissions = ScriptingPermissions.getPermissiveScriptingPermissions();
@@ -148,7 +148,7 @@ class ScriptingRegistration {
 				    .getProperty(ScriptingPermissions.RESOURCES_EXECUTE_SCRIPTS_WITHOUT_READ_RESTRICTION);
 				final String writeAccessString = properties
 				.getProperty(ScriptingPermissions.RESOURCES_EXECUTE_SCRIPTS_WITHOUT_WRITE_RESTRICTION);
-				final String classpath = properties.getProperty(ScriptingEngine.RESOURCES_SCRIPT_CLASSPATH);
+				final String classpath = properties.getProperty(ScriptResources.RESOURCES_SCRIPT_CLASSPATH);
 				final boolean readAccess = readAccessString != null && Boolean.parseBoolean(readAccessString);
 				final boolean writeAccess = writeAccessString != null && Boolean.parseBoolean(writeAccessString);
 				final boolean classpathIsSet = classpath != null && classpath.length() > 0;
@@ -191,32 +191,36 @@ class ScriptingRegistration {
 			}
 		});
 		registerScriptAddOns();
-		addPropertiesToOptionPanel();
-		final MenuBuilder menuBuilder = modeController.getUserInputListenerFactory().getMenuBuilder();
-		modeController.addAction(new ScriptEditor());
-		modeController.addAction(new ExecuteScriptForAllNodes());
-		modeController.addAction(new ExecuteScriptForSelectionAction());
-		final ManageAddOnsAction manageAddOnsAction = new ManageAddOnsAction();
-		modeController.addAction(manageAddOnsAction);
-		modeController.addExtension(AddOnInstaller.class, new AddOnInstaller() {
-			public void install(final URL url) {
-				final ManageAddOnsDialog dialog = manageAddOnsAction.getDialog();
-				dialog.install(url);
-            }
-		});
-		final ScriptingConfiguration configuration = new ScriptingConfiguration();
-		ScriptingEngine.setClasspath(configuration.getClasspath());
-		modeController.addMenuContributor(new IMenuContributor() {
-			public void updateMenus(ModeController modeController, MenuBuilder builder) {
-				registerScripts(menuBuilder, configuration);
-			}
-		});
-		createUserScriptsDirectory();
-		FilterController.getCurrentFilterController().getConditionFactory().addConditionController(10,
-		    new ScriptConditionController());
+		if(! modeController.getController().getViewController().isHeadless()){
+			final IUserInputListenerFactory userInputListenerFactory = modeController.getUserInputListenerFactory();
+			addPropertiesToOptionPanel();
+			final MenuBuilder menuBuilder = userInputListenerFactory.getMenuBuilder();
+			modeController.addAction(new ScriptEditor());
+			modeController.addAction(new ExecuteScriptForAllNodes());
+			modeController.addAction(new ExecuteScriptForSelectionAction());
+			final ManageAddOnsAction manageAddOnsAction = new ManageAddOnsAction();
+			modeController.addAction(manageAddOnsAction);
+			modeController.addExtension(AddOnInstaller.class, new AddOnInstaller() {
+				public void install(final URL url) {
+					final ManageAddOnsDialog dialog = manageAddOnsAction.getDialog();
+					dialog.install(url);
+				}
+			});
+			final ScriptingConfiguration configuration = new ScriptingConfiguration();
+			ScriptCompiler.compileScriptsOnPath(ScriptResources.getClasspath());
+			modeController.addMenuContributor(new IMenuContributor() {
+				public void updateMenus(ModeController modeController, MenuBuilder builder) {
+					registerScripts(menuBuilder, configuration);
+				}
+			});
+			createUserScriptsDirectory();
+			createUserLibDirectory();
+		}
+		FilterController.getCurrentFilterController().getConditionFactory().addConditionController(10, 
+			new ScriptConditionController());
 	}
 
-	private void registerScriptAddOns() {
+    private void registerScriptAddOns() {
 		File[] addonXmlFiles = AddOnsController.getController().getAddOnsDir().listFiles(new FilenameFilter() {
 			public boolean accept(File dir, String name) {
 				return name.endsWith(".script.xml");
@@ -243,27 +247,35 @@ class ScriptingRegistration {
 	}
 
 	private void createUserScriptsDirectory() {
-		final File scriptDir = ScriptingEngine.getUserScriptDir();
+		final File scriptDir = ScriptResources.getUserScriptsDir();
 		if (!scriptDir.exists()) {
 			LogUtils.info("creating user scripts directory " + scriptDir);
 			scriptDir.mkdirs();
 		}
 	}
 
-	private void registerScripts(final MenuBuilder menuBuilder, ScriptingConfiguration configuration) {
+	private void createUserLibDirectory() {
+		final File libDir = ScriptResources.getUserLibDir();
+		if (!libDir.exists()) {
+			LogUtils.info("creating user lib directory " + libDir);
+			libDir.mkdirs();
+		}
+	}
+
+    private void registerScripts(final MenuBuilder menuBuilder, ScriptingConfiguration configuration) {
 		final HashSet<String> registeredLocations = new HashSet<String>();
 		for (final String scriptsParentLocation : ScriptingConfiguration.getScriptsParentLocations()) {
 			final String scriptsLocation = ScriptingConfiguration.getScriptsLocation(scriptsParentLocation);
 			addSubMenu(menuBuilder, scriptsParentLocation, scriptsLocation, TextUtils.getText("ExecuteScripts.text"));
 			registeredLocations.add(scriptsLocation);
-			if (configuration.getNameScriptMap().isEmpty()) {
+			if (configuration.getMenuTitleToPathMap().isEmpty()) {
 				final String message = "<html><body><em>" + TextUtils.getText("ExecuteScripts.noScriptsAvailable")
 				        + "</em></body></html>";
 				menuBuilder.addElement(scriptsLocation, new JMenuItem(message), 0);
 			}
-			for (final Entry<String, String> entry : configuration.getNameScriptMap().entrySet()) {
+			for (final Entry<String, String> entry : configuration.getMenuTitleToPathMap().entrySet()) {
 				final String scriptName = entry.getKey();
-				final ScriptMetaData metaData = configuration.getNameScriptMetaDataMap().get(scriptName);
+				final ScriptMetaData metaData = configuration.getMenuTitleToMetaDataMap().get(scriptName);
 				// in the worst case three actions will cache a script - should not matter that much since it's unlikely
 				// that one script is used in multiple modes by the same user
 				for (final ExecutionMode executionMode : metaData.getExecutionModes()) {
