@@ -7,16 +7,21 @@ import groovy.lang.Closure;
 
 import java.io.File;
 import java.net.URL;
+import java.util.ArrayList;
 import java.util.Iterator;
 import java.util.List;
 
 import javax.swing.Icon;
+import javax.swing.filechooser.FileFilter;
 
 import org.freeplane.core.resources.ResourceController;
 import org.freeplane.core.ui.IEditHandler.FirstAction;
 import org.freeplane.core.undo.IUndoHandler;
 import org.freeplane.core.util.FreeplaneIconUtils;
 import org.freeplane.core.util.FreeplaneVersion;
+import org.freeplane.core.util.LogUtils;
+import org.freeplane.features.export.mindmapmode.ExportController;
+import org.freeplane.features.export.mindmapmode.IExportEngine;
 import org.freeplane.features.filter.condition.ICondition;
 import org.freeplane.features.map.IMapSelection;
 import org.freeplane.features.map.MapModel;
@@ -79,16 +84,21 @@ class ControllerProxy implements Proxy.Controller {
 		    .getSortedSelection(differentSubtrees), scriptContext);
 	}
 
-	public void select(final Node toSelect) {
-		final NodeModel nodeModel = ((NodeProxy) toSelect).getDelegate();
-		Controller.getCurrentController().getSelection().selectAsTheOnlyOneSelected(nodeModel);
-	}
+    public void select(final Node toSelect) {
+        if (toSelect != null) {
+            final NodeModel nodeModel = ((NodeProxy) toSelect).getDelegate();
+            Controller.getCurrentModeController().getMapController().displayNode(nodeModel);
+            Controller.getCurrentController().getSelection().selectAsTheOnlyOneSelected(nodeModel);
+        }
+    }
 
-	public void selectBranch(final Node branchRoot) {
-		final NodeModel nodeModel = ((NodeProxy) branchRoot).getDelegate();
-		Controller.getCurrentModeController().getMapController().displayNode(nodeModel);
-		Controller.getCurrentController().getSelection().selectBranch(nodeModel, false);
-	}
+    public void selectBranch(final Node branchRoot) {
+        if (branchRoot != null) {
+            final NodeModel nodeModel = ((NodeProxy) branchRoot).getDelegate();
+            Controller.getCurrentModeController().getMapController().displayNode(nodeModel);
+            Controller.getCurrentController().getSelection().selectBranch(nodeModel, false);
+        }
+    }
 
 	public void selectMultipleNodes(final List<Node> toSelect) {
 		final IMapSelection selection = Controller.getCurrentController().getSelection();
@@ -132,6 +142,10 @@ class ControllerProxy implements Proxy.Controller {
 		return Controller.getCurrentController().getViewController();
 	}
 
+	private IMapViewManager getMapViewManager() {
+		return Controller.getCurrentController().getMapViewManager();
+	}
+
 	public void setStatusInfo(final String infoPanelKey, final String info) {
 		final ViewController viewController = getViewController();
 		viewController.addStatusInfo(infoPanelKey, info, null);
@@ -225,14 +239,46 @@ class ControllerProxy implements Proxy.Controller {
 	}
 
     public float getZoom() {
-	    return getViewController().getZoom();
+	    return getMapViewManager().getZoom();
     }
     
     public void setZoom(float ratio) {
-    	getViewController().setZoom(ratio);
+    	getMapViewManager().setZoom(ratio);
     }
 
     public boolean isInteractive() {
         return !Boolean.parseBoolean(System.getProperty("nonInteractive"));
     }
+
+    public List<String> getExportTypeDescriptions() {
+        final ArrayList<String> list = new ArrayList<String>();
+        for (FileFilter fileFilter : ExportController.getContoller().getFileFilters()) {
+            list.add(fileFilter.getDescription());
+        }
+        return list;
+    }
+
+    public void export(Map map, File destFile, String exportTypeDescription, boolean overwriteExisting) {
+        final FileFilter filter = findExportFileFilterByDescription(exportTypeDescription);
+        if (filter == null) {
+            throw new IllegalArgumentException("no export defined for '" + exportTypeDescription + "'");
+        }
+        else if (!overwriteExisting && destFile.exists()) {
+            throw new RuntimeException("destination file " + destFile.getAbsolutePath()
+                    + " already exists - set overwriteExisting to true?");
+        }
+        else {
+            final IExportEngine exportEngine = ExportController.getContoller().getFilterMap().get(filter);
+            exportEngine.export(((MapProxy) map).getDelegate(), destFile);
+            LogUtils.info("exported " + map.getFile() + " to " + destFile.getAbsolutePath());
+        }
+    }
+
+    private FileFilter findExportFileFilterByDescription(String exportTypeDescription) {
+        for (FileFilter fileFilter : ExportController.getContoller().getFileFilters()) {
+            if (fileFilter.getDescription().equals(exportTypeDescription))
+                return fileFilter;
+        }
+        return null;
+    }
 }
