@@ -6,6 +6,7 @@ package org.freeplane.plugin.script.proxy;
 import java.net.URL;
 import java.util.ArrayList;
 import java.util.Collections;
+import java.util.Iterator;
 import java.util.List;
 
 import org.freeplane.features.icon.IconController;
@@ -93,6 +94,27 @@ class IconsProxy extends AbstractProxy<NodeModel> implements Proxy.Icons {
 	    return Collections.unmodifiableList(list);
 	}
 
+    public Iterator<String> iterator() {
+        return new Iterator<String>() {
+            final Iterator<String> iterator = getIcons().iterator();
+
+            @Override
+            public boolean hasNext() {
+                return iterator.hasNext();
+            }
+
+            @Override
+            public String next() {
+                return iterator.next();
+            }
+
+            @Override
+            public void remove() {
+                throw new UnsupportedOperationException("icons iterator is read-only");
+            }
+        };
+    }
+
 	public boolean remove(final int index) {
 		if (index >= size()) {
 			return false;
@@ -114,6 +136,10 @@ class IconsProxy extends AbstractProxy<NodeModel> implements Proxy.Icons {
 	public boolean removeIcon(final String iconID) {
 		return remove(iconID);
 	}
+	
+	public void clear() {
+	    getIconController().removeAllIcons(getDelegate());
+	}
 
     /** make <code>if (node.icons) println "has some icon"</code> work. */
     public boolean asBoolean() {
