@@ -5,6 +5,7 @@ package org.freeplane.plugin.script.proxy;
 
 import groovy.lang.Closure;
 
+import java.util.Arrays;
 import java.util.Collection;
 import java.util.Date;
 import java.util.List;
@@ -15,21 +16,29 @@ import org.codehaus.groovy.runtime.DefaultGroovyMethods;
 import org.codehaus.groovy.runtime.typehandling.NumberMath;
 import org.freeplane.core.undo.IActor;
 import org.freeplane.core.util.HtmlUtils;
+import org.freeplane.core.util.LogUtils;
+import org.freeplane.core.util.TextUtils;
 import org.freeplane.features.clipboard.ClipboardController;
 import org.freeplane.features.clipboard.mindmapmode.MClipboardController;
 import org.freeplane.features.encrypt.Base64Coding;
+import org.freeplane.features.encrypt.EncryptionController;
+import org.freeplane.features.encrypt.PasswordStrategy;
+import org.freeplane.features.encrypt.mindmapmode.MEncryptionController;
 import org.freeplane.features.filter.condition.ICondition;
 import org.freeplane.features.format.IFormattedObject;
 import org.freeplane.features.link.ConnectorModel;
 import org.freeplane.features.link.LinkController;
 import org.freeplane.features.link.mindmapmode.MLinkController;
+import org.freeplane.features.map.EncryptionModel;
 import org.freeplane.features.map.FreeNode;
+import org.freeplane.features.map.MapController.Direction;
 import org.freeplane.features.map.MapModel;
 import org.freeplane.features.map.MapNavigationUtils;
 import org.freeplane.features.map.NodeModel;
-import org.freeplane.features.map.MapController.Direction;
 import org.freeplane.features.map.mindmapmode.MMapController;
 import org.freeplane.features.mode.Controller;
+import org.freeplane.features.nodelocation.LocationController;
+import org.freeplane.features.nodelocation.mindmapmode.MLocationController;
 import org.freeplane.features.nodestyle.NodeStyleController;
 import org.freeplane.features.nodestyle.mindmapmode.MNodeStyleController;
 import org.freeplane.features.note.NoteController;
@@ -38,8 +47,10 @@ import org.freeplane.features.note.mindmapmode.MNoteController;
 import org.freeplane.features.text.DetailTextModel;
 import org.freeplane.features.text.TextController;
 import org.freeplane.features.text.mindmapmode.MTextController;
+import org.freeplane.features.ui.ViewController;
 import org.freeplane.plugin.script.ScriptContext;
 import org.freeplane.plugin.script.proxy.Proxy.Attributes;
+import org.freeplane.plugin.script.proxy.Proxy.Cloud;
 import org.freeplane.plugin.script.proxy.Proxy.Node;
 import org.freeplane.plugin.script.proxy.Proxy.Reminder;
 
@@ -149,16 +160,21 @@ class NodeProxy extends AbstractProxy<NodeModel> implements Node {
 
 	// Node: R/W
 	public void setDetails(Object details) {
-		final MTextController textController = (MTextController) TextController.getController();
-		if (details == null) {
+		setDetailsText(convertConvertibleToHtml(details));
+	}
+
+	// Node: R/W
+    public void setDetailsText(String html) {
+        final MTextController textController = (MTextController) TextController.getController();
+		if (html == null) {
 			textController.setDetailsHidden(getDelegate(), false);
 			textController.setDetails(getDelegate(), null);
 		}
 		else{
-			textController.setDetails(getDelegate(), convertConvertibleToHtml(details));
+			textController.setDetails(getDelegate(), html);
 		}
-	}
-
+    }
+	
 	// Node: R/W
 	public void setHideDetails(boolean hide) {
 		MTextController controller = (MTextController) MTextController.getController();
@@ -176,6 +192,11 @@ class NodeProxy extends AbstractProxy<NodeModel> implements Node {
 		return ProxyUtils.createListOfChildren(getDelegate(), getScriptContext());
 	}
 
+    // NodeRO: R
+    public Cloud getCloud() {
+        return new CloudProxy(this);
+    }
+
 	// NodeRO: R
 	public Collection<Proxy.Connector> getConnectorsIn() {
 		return new ConnectorInListProxy(this);
@@ -189,7 +210,7 @@ class NodeProxy extends AbstractProxy<NodeModel> implements Node {
 	// NodeRO: R
 	public Convertible getDetails() {
 		final String detailsText = DetailTextModel.getDetailTextText(getDelegate());
-		return (detailsText == null) ? null : new ConvertibleText(getDelegate(), getScriptContext(), detailsText);
+		return (detailsText == null) ? null : new ConvertibleHtmlText(getDelegate(), getScriptContext(), detailsText);
 	}
 	
 	// NodeRO: R
@@ -253,7 +274,7 @@ class NodeProxy extends AbstractProxy<NodeModel> implements Node {
 	// NodeRO: R
 	public Convertible getNote() {
 		final String noteText = getNoteText();
-		return (noteText == null) ? null : new ConvertibleNoteText(getDelegate(), getScriptContext());
+		return (noteText == null) ? null : new ConvertibleNoteText(getDelegate(), getScriptContext(), noteText);
 	}
 
 	// NodeRO: R
@@ -268,6 +289,11 @@ class NodeProxy extends AbstractProxy<NodeModel> implements Node {
 		return getParent();
 	}
 
+    // NodeRO: R
+    public List<Node> getPathToRoot() {
+        return ProxyUtils.createNodeList(Arrays.asList(getDelegate().getPathToRoot()), getScriptContext());
+    }
+
     // NodeRO: R
     public Node getNext() {
         final NodeModel node = MapNavigationUtils.findNext(Direction.FORWARD, getDelegate(), null);
@@ -470,9 +496,9 @@ class NodeProxy extends AbstractProxy<NodeModel> implements Node {
 	}
 
 	// Node: R/W
-	public void setNoteText(final String text) {
+	public void setNoteText(final String html) {
 		final MNoteController noteController = (MNoteController) NoteController.getController();
-		noteController.setNoteText(getDelegate(), text);
+		noteController.setNoteText(getDelegate(), html);
 	}
 
 	// Node: R/W
@@ -694,4 +720,86 @@ class NodeProxy extends AbstractProxy<NodeModel> implements Node {
 	public Number previous() {
 		return NumberMath.subtract(this.getTo().getNum0(), ONE);
 	}
+
+    public boolean hasEncryption() {
+        return getEncryptionModel() != null;
+    }
+
+    public boolean isEncrypted() {
+        final EncryptionModel encryptionModel = getEncryptionModel();
+        return encryptionModel != null && !encryptionModel.isAccessible();
+    }
+
+    public void encrypt(String password) {
+        if (!isEncrypted())
+            getEncryptionController().toggleCryptState(getDelegate(), makePasswordStrategy(password));
+    }
+
+    public void decrypt(String password) {
+        if (isEncrypted())
+            getEncryptionController().toggleCryptState(getDelegate(), makePasswordStrategy(password));
+    }
+    
+    public void removeEncryption(String password) {
+        getEncryptionController().removeEncryption(getDelegate(), makePasswordStrategy(password));
+    }
+
+    private PasswordStrategy makePasswordStrategy(final String password) {
+        return new PasswordStrategy() {
+            public StringBuilder getPassword() {
+                return new StringBuilder(password);
+            }
+
+            public StringBuilder getPasswordWithConfirmation() {
+                return getPassword();
+            }
+
+            public void onWrongPassword() {
+                LogUtils.info("wrong password for node " + getDelegate());
+                setStatusInfo(TextUtils.getText("accessories/plugins/EncryptNode.properties_wrong_password"));
+            }
+
+            public boolean isCancelled() {
+                return false;
+            }
+        };
+    }
+
+    private void setStatusInfo(String text) {
+        final ViewController viewController = Controller.getCurrentController().getViewController();
+        viewController.out(text);
+    }
+    
+    private MEncryptionController getEncryptionController() {
+        return (MEncryptionController) Controller.getCurrentModeController().getExtension(EncryptionController.class);
+    }
+
+    private EncryptionModel getEncryptionModel() {
+        return EncryptionModel.getModel(getDelegate());
+    }
+
+
+	public int getHorizontalShift(){
+		return LocationController.getController().getHorizontalShift(getDelegate());
+	}
+
+	public void setHorizontalShift(final int horizontalShift){
+		((MLocationController) LocationController.getController()).setHorizontalShift(getDelegate(), horizontalShift);
+	}
+
+	public int getVerticalShift(){
+		return LocationController.getController().getVerticalShift(getDelegate());
+	}
+
+	public void setVerticalShift(final int verticalShift){
+		((MLocationController) LocationController.getController()).setVerticalShift(getDelegate(), verticalShift);
+	}
+
+	public int getMinimalDistanceBetweenChildren(){
+		return LocationController.getController().getMinimalDistanceBetweenChildren(getDelegate());
+	}
+
+	public void setMinimalDistanceBetweenChildren(final int minimalDistanceBetweenChildren){
+		((MLocationController) LocationController.getController()).setMinimalDistanceBetweenChildren(getDelegate(), minimalDistanceBetweenChildren);
+	}
 }
